==> embed_1.1.0.tar.gz: embed/R/embed-package.R <==
#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @import recipes
#' @import rlang
#' @importFrom dplyr %>%
#' @importFrom dplyr arrange
#' @importFrom dplyr bind_cols
#' @importFrom dplyr bind_rows
#' @importFrom dplyr contains
#' @importFrom dplyr ends_with
#' @importFrom dplyr filter
#' @importFrom dplyr left_join
#' @importFrom dplyr mutate
#' @importFrom dplyr one_of
#' @importFrom glue glue
#' @importFrom keras backend
#' @importFrom keras compile
#' @importFrom keras fit
#' @importFrom keras get_layer
#' @importFrom keras keras_model
#' @importFrom keras keras_model_sequential
#' @importFrom keras layer_concatenate
#' @importFrom keras layer_dense
#' @importFrom keras layer_embedding
#' @importFrom keras layer_flatten
#' @importFrom keras layer_input
#' @importFrom lifecycle deprecated
#' @importFrom stats as.formula
#' @importFrom stats binomial
#' @importFrom stats coef
#' @importFrom stats complete.cases
#' @importFrom stats gaussian
#' @importFrom stats glm
#' @importFrom stats model.matrix
#' @importFrom stats na.omit
#' @importFrom stats setNames
#' @importFrom tibble as_tibble
#' @importFrom tibble rownames_to_column
#' @importFrom tibble tibble
#' @importFrom tidyr gather
#' @importFrom utils capture.output
#' @importFrom utils compareVersion
#' @importFrom utils globalVariables
#' @importFrom utils packageVersion
#' @importFrom utils stack
#' @importFrom uwot umap
#' @importFrom uwot umap_transform
#' @importFrom withr with_seed
## usethis namespace: end
NULL

==> embed_1.1.1.tar.gz: embed/R/embed-package.R <==
#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @import recipes
#' @import rlang
#' @importFrom dplyr %>%
#' @importFrom dplyr arrange
#' @importFrom dplyr bind_rows
#' @importFrom dplyr contains
#' @importFrom dplyr ends_with
#' @importFrom dplyr filter
#' @importFrom dplyr left_join
#' @importFrom dplyr mutate
#' @importFrom dplyr one_of
#' @importFrom glue glue
#' @importFrom keras backend
#' @importFrom keras compile
#' @importFrom keras fit
#' @importFrom keras get_layer
#' @importFrom keras keras_model
#' @importFrom keras keras_model_sequential
#' @importFrom keras layer_concatenate
#' @importFrom keras layer_dense
#' @importFrom keras layer_embedding
#' @importFrom keras layer_flatten
#' @importFrom keras layer_input
#' @importFrom lifecycle deprecated
#' @importFrom stats as.formula
#' @importFrom stats binomial
#' @importFrom stats coef
#' @importFrom stats complete.cases
#' @importFrom stats gaussian
#' @importFrom stats glm
#' @importFrom stats model.matrix
#' @importFrom stats na.omit
#' @importFrom stats setNames
#' @importFrom tibble as_tibble
#' @importFrom tibble rownames_to_column
#' @importFrom tibble tibble
#' @importFrom tidyr gather
#' @importFrom utils capture.output
#' @importFrom utils compareVersion
#' @importFrom utils globalVariables
#' @importFrom utils packageVersion
#' @importFrom utils stack
#' @importFrom uwot umap
#' @importFrom uwot umap_transform
#' @importFrom vctrs vec_cbind
#' @importFrom withr with_seed
## usethis namespace: end
NULL
